@@ -26,27 +26,36 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 sub new {
-    my($clsname, $writer, $zipname) =@_;
+    my($clsname, $writer, $zipname, @rest) =@_;
     my $self = { 
 	writer=>$writer,
 	name=>$zipname,
 	zip=>Archive::Zip->new(),
-	
+	compression=>9,
+	@rest,
     };
     bless $self, $clsname;
     return $self;
 }
 
+sub Compression {
+    my $self = shift;
+    my $oval = $self->{compression};
+    $self->{compression} = shift;
+    return $oval;
+}
+
 sub AddFile {
     my($self, $name, $newname) = @_;
     my $writer = $self->{writer};
     my $zip = $self->{zip};
     my $extra = $newname ? " as $newname" : "";
     $writer->dataElement('li', "Adding file $name$extra to zip archive $self->{name}\n");
+    return 1 if ($self->{dryrun});
     return $zip->addFile($name, $newname);
 }
 
@@ -56,6 +65,7 @@ sub AddTree {
     my $zip = $self->{zip};
     my $extra = $newname ? " as $newname" : "";
     $writer->dataElement('li', "Adding tree $name$extra to zip archive $self->{name}\n");
+    return 1 if ($self->{dryrun});
     return $zip->addTree($name, $newname, $func) == AZ_OK;
 }
 
@@ -63,7 +73,11 @@ sub Close {
     my($self) = @_;
     my $writer = $self->{writer};
     my $zip = $self->{zip};
+    foreach my $zm ($zip->members()) {
+	$zm->desiredCompressionLevel($self->{compression});
+    }
     $writer->dataElement('li', "Writing out zip file $self->{name}\n");
+    return 1 if ($self->{dryrun});
     return $zip->writeToFileNamed($self->{name}) == AZ_OK;
 }
 
@@ -81,6 +95,7 @@ PANT::Zip - PANT support for zipping up files
   $zipper = Zip("foo.zip);
   $zipper->AddFile("test-thing", "thing");
   $zipper->AddTree("buildlib", "lib");
+  $zipper->Compression(9);
   $zipper->Close();  
 
 =head1 ABSTRACT
@@ -98,26 +113,35 @@ It is really just a thin wrapping layer around Archive::Zip.
 
 =head1 EXPORTS
 
-=head2 new($xml, "foo.zip");
-
-Constructor for a test object. Requires an XML::Writer object and a zip name as parameters, which it
-will use for subsequent log construction. The PANT function ZIP calls this constructor
-with the current xml stream, and passes on the arguments for you. So normally you would call
-it via the accessor.
-
+None
 
 =head1 METHODS
 
+=head2 new($xml, "foo.zip");
+
+Constructor for a test object. Requires an XML::Writer object and a
+zip name as parameters, which it will use for subsequent log
+construction. The PANT function ZIP calls this constructor with the
+current xml stream, and passes on the arguments for you. So normally
+you would call it via the accessor.
+
 =head2 AddFile(file, newname)
 
-Adds the given file to the zip, optionally renaming it on the way if a 2nd argument is given.
+Adds the given file to the zip, optionally renaming it on the way if a
+2nd argument is given.
 
 =head2 AddTree(directory, dirname, func)
 
-Adds the given directory tree to the zip, recursively. If the newname is given, then
-the base directory will be renamed to that. Finally the 3rd parameter if present is a
-subroutine reference to be called for each prospective file. It can examine $_ and return
-true/false to add it.
+Adds the given directory tree to the zip, recursively. If the newname
+is given, then the base directory will be renamed to that. Finally the
+3rd parameter if present is a subroutine reference to be called for
+each prospective file. It can examine $_ and return true/false to add
+it.
+
+=head2 Compression(no)
+
+Set the overall archive compression number. This is a number between 0 and 9,
+0 being no compression, and 9 being maximum compression.
 
 =head1 SEE ALSO
 
@@ -127,7 +151,7 @@ Makes use of XML::Writer to construct the build log.
 
 =head1 AUTHOR
 
-Julian Onions, E<lt>julianonions@yahoo.nospam-co.uk<gt>
+Julian Onions, E<lt>julianonions@yahoo.nospam-co.ukE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
